@@ -26,23 +26,30 @@
 #define GMIC_QT_LOGGER_H
 
 #include <cstdio>
-#include "gmic_qt.h"
+#include "GmicQt.h"
 
 class QString;
 
+namespace GmicQt
+{
+
 class Logger {
 public:
-  enum Mode
+  enum class Mode
   {
     StandardOutput,
     File
   };
 
   static void setMode(const Mode mode);
-  static void setMode(const GmicQt::OutputMessageMode mode);
+  static void setMode(const OutputMessageMode mode);
   static void clear();
   static void close();
-  static void log(const QString & message);
+  static void log(const QString & message, const QString & hint, bool space = false);
+  static void error(const QString & message, bool space = false);
+  static void warning(const QString & message, bool space = false);
+  static void note(const QString & message, bool space = false);
+  static void log(const QString & message, bool space = false);
   Logger() = delete;
 
 private:
@@ -50,4 +57,6 @@ private:
   static Mode _currentMode;
 };
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_LOGGER_H
